@@ -36,7 +36,7 @@ def pythagorean(a, b):
 	c=sqrtofn(c2)
 	return c
 
- 
+
 def Fibonacci(n):
     if n<=0:
         print("Incorrect input")
@@ -48,3 +48,10 @@ def Fibonacci(n):
         return 1
     else:
         return Fibonacci(n-1)+Fibonacci(n-2)
+
+def sin(angle):
+	return math.sin(angle)
+def cosine(angle):
+	return math.cos(angle)
+def tan(angle):
+	return math.tan(angle)
